function varargout = StewSIM_1(varargin)
% STEWSIM_1 MATLAB code for StewSIM_1.fig
%      STEWSIM_1, by itself, creates a new STEWSIM_1 or raises the existing
%      singleton*.
%
%      H = STEWSIM_1 returns the handle to a new STEWSIM_1 or the handle to
%      the existing singleton*.
%
%      STEWSIM_1('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in STEWSIM_1.M with the given input arguments.
%
%      STEWSIM_1('Property','Value',...) creates a new STEWSIM_1 or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before StewSIM_1_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to StewSIM_1_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help StewSIM_1

% Last Modified by GUIDE v2.5 21-Dec-2011 15:56:19

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @StewSIM_1_OpeningFcn, ...
                   'gui_OutputFcn',  @StewSIM_1_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before StewSIM_1 is made visible.
function StewSIM_1_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to StewSIM_1 (see VARARGIN)

% Choose default command line output for StewSIM_1
handles.output = hObject;

% Screen = get(0, 'ScreenSize');
% ScreenFigure = get(gcf , 'Position');
% newScreenFigure = (Screen/2)-ScreenFigure;
% ScreenFigure(1) = newScreenFigure(3);
% ScreenFigure(2) = newScreenFigure(4);
% set(gcf, 'Position', ScreenFigure );
%show image on axes

haxesSTEWSIM = gca;

set( haxesSTEWSIM , 'Tag' , 'axesSTEWSIM' );
setappdata( 0 , 'haxesSTEWSIM' , haxesSTEWSIM );

% haxesSTEWSIM = getappdata( 0, 'haxesSTEWSIM');
% if ( isempty( haxesSTEWSIM )  ) 
%     %%first time 
%     setappdata( 0 , 'haxesSTEWSIM' , haxesSTEWSIM );
% else figure(haxesSTEWSIM);
% end;


axes(haxesSTEWSIM);
imshow('StewSIM-4.tif');

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes StewSIM_1 wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = StewSIM_1_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on button press in pushbutton1.
function pushbutton1_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

hStewSIM = gcf;
set(hStewSIM,'visible','off');
setappdata(0,'hStewSIM',hStewSIM);
%delete(handles.figure1);

%%DesignGSP;
DesignCircumferential;


% --- Executes on button press in pushbutton3.
function pushbutton3_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
%delete(handles.figure1);
%ters_kinematik_gui_anaprog
hStewSIM = gcf;
set(hStewSIM,'visible','off');
setappdata(0,'hStewSIM',hStewSIM);


%select_a_file_please;
AnalysisGSP;

% --- Executes during object creation, after setting all properties.
function axesSTEWSIM_CreateFcn(hObject, eventdata, handles)
% hObject    handle to axesSTEWSIM (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: place code in OpeningFcn to populate axesSTEWSIM
imshow('stewart.tif');


% --- Executes during object creation, after setting all properties.
function figure1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to figure1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called


% --- Executes on button press in pushbutton4.
function pushbutton4_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
delete(gcf);


% --- Executes on button press in pb_DesignCircumferential.
function pb_DesignCircumferential_Callback(hObject, eventdata, handles)
% hObject    handle to pb_DesignCircumferential (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
hStewSIM = gcf;
set(hStewSIM,'visible','off');
setappdata(0,'hStewSIM',hStewSIM);
%delete(handles.figure1);

DesignCircumferential;
